@@ -3,7 +3,7 @@ package Alien::Base::ModuleBuild;
 use strict;
 use warnings;
 
-our $VERSION = '0.000_006';
+our $VERSION = '0.000_007';
 $VERSION = eval $VERSION;
 
 use parent 'Module::Build';
@@ -209,7 +209,7 @@ sub alien_init_temp_dir {
 
 sub ACTION_code {
   my $self = shift;
-  $self->depends_on('alien');
+  $self->depends_on('alien') unless $self->notes('ACTION_alien_completed');
   $self->SUPER::ACTION_code;
 }
 
@@ -286,6 +286,9 @@ sub ACTION_alien {
   } 
 
   $self->config_data( version => $pc_version || $version );
+
+  # prevent building multiple times (on M::B::dispatch)
+  $self->notes( 'ACTION_alien_completed' => 1 );
   return;
 }
 
@@ -431,7 +434,7 @@ sub alien_generate_manual_pkgconfig {
 
   #if no provides_libs then generate -l list from found files
   unless ($provides_libs) {
-    my @files = map { "-l$_" } @{$paths->{files}};
+    my @files = map { "-l$_" } @{$paths->{so_files}};
     $provides_libs = join( ' ', @files );
   } 
 
